@@ -13,13 +13,13 @@ print.MSD <- function(x, ...) {
 	invisible(x)
 }
 
-plot.MSD <- function(x, type='h', ...) {
+plot.MSD <- function(x, type='h', ylab="MSD", ...) {
 	plot.local<-function(x, y, axes, ...) plot(x, y, axes=FALSE, ...)
 	ldots<-list(...)
 	axes <- if(is.null(ldots$axes)) TRUE else ldots$ann 
 	frame.plot <- if(is.null(ldots$frame.plot)) axes else ldots$frame.plot 
 	
-	plot.local(1:length(x), c(x), type=type, ...)
+	plot.local(1:length(x), c(x), type=type, ylab=ylab, ...)
 	if(frame.plot) box()
 	if(axes) {
 		axis(1, at=1:length(x), labels=names(x), ...)
@@ -32,6 +32,8 @@ barplot.MSD <- function(height, ylab="MSD", names.arg=names(height),
 	crit.vals=TRUE, lty.crit=c(2,1), col.crit=2, lwd.crit=c(1,2), 
 	probs=c(0.95, 0.99), n=length(height), ... ) {
 	
+	if(is.null(names.arg)) names.arg <- paste(1:length(height))
+	
 	mids <- barplot(as.vector(height), ylab=ylab, names.arg=names.arg, ...)
 	
 	if(crit.vals && length(na.omit(probs)) > 0) {
